*===================================================================
*     
*     Jet Propulsion Laboratory
*     
*     Atmospheric InfraRed Sounder
*     
*     [ Subsystem or Program Name ]
*
*      Copyright (c) 1998 - California Institute of Technology
*              U.S. Government Sponsorship under NASA
*                Contract NAS7-1270 is acknowledged
*===================================================================

      integer    MAXDESCR
      parameter (MAXDESCR=16)	! RBO Used to be 10 or 16 ?
      integer    MAXLEV
      parameter (MAXLEV=100)    ! Max number of pressure levels
      integer    MAXCLD
      parameter (MAXCLD=2)      ! Max number of cloud layers
      integer    MAXEMIS
      parameter (MAXEMIS=100)   ! Max freq intervals for IR emiss
      integer    MXCEMIS
      parameter (MXCEMIS=7)     ! Max freq intervals for cld emiss
      integer    MWHINGE
      parameter (MWHINGE=7)     ! MW hinge points for surface
      integer    MAXSPARE
      parameter (MAXSPARE=30)   ! Max # of spare data footprints

*===================================================================

      structure /IO_struct/
	logical   unformatted
	integer   iounit
	integer   pcf_logical_id
	character filename*256
	character oldornew*3
	character pgsornot*3
	character version*5
      end structure

*===================================================================

        STRUCTURE /Level2_header/
        integer   nobs               !
        integer   nemis              ! Number of surface emissivity bands
        integer   ncemis             ! Number of cloud emissivity bands
        integer   numlev             ! The maximum number of levels
        integer   ndesc              ! dimension for descr
        real      pobs(MAXLEV)       ! Pressure levels, lower boundary
                                     ! deprecated: use gran.l2.pobs
        real      pdiff(MAXLEV)      ! Pressure differences.
                                     ! deprecated: use gran.l2.pdiff
        character descr(MAXDESCR)*120      ! descriptions
        end STRUCTURE

*===================================================================

      STRUCTURE /airs_level2/

         double precision  tai_time
         double precision  alat
         double precision  alon

         real sec
         real satheight
         real viewang
         real satzen
         real satazi
         real solzen
         real solazi

         real topog
         real topog_err
         real landFrac
         real landFrac_err
         
         integer year
         integer month
         integer day
         integer hour
         integer minute
         integer footprint_num

         character idprof*8

         integer   daynite      ! Day-Night flag
         real      cossun       ! cosine of solar zenith angle
         real      psurf        ! surface pressure
         real      tsurf        ! surface temperature
         integer   nsurf        ! surface level index
         integer   nsurfstd     ! surface level index
         real      tair(MAXLEV) ! temp profile in Kelvins
                                ! Note: tairmw profile is MAXLEV but
                                ! error estimate is STDLEV
         real      tairsurf     ! surface air temperature
         real      h2ocd(MAXLEV) ! water vapor column density
         real      ozocd(MAXLEV) ! ozone column density
         real      wlcd(MAXLEV) ! Liquid water column density
         integer   ciw(MAXLEV)  ! cloud=0/ice=1 switch
         real      co2ppmv      ! column average dry co2 
                                !volumetric mixing ratio
         real      cocd(MAXLEV) ! CO molecular column density
         real      ch4cd(MAXLEV) ! Methane molecular column density
         real      emisir(MAXEMIS) ! IR surface emissivities
         real      sfcTbMW(MWHINGE) ! Microwave surface brightness Temperature
         byte      MWSurfClass  ! Surface class from MW:
                                ! 1 for land;
                                ! 2 for ocean;
                                ! 3 for first-year sea-ice;
                                ! 4 for multi-year sea-ice;
                                ! 5 for snow;
                                ! 6 for glacier;
                                ! more TBD
         real      emismw       ! MW surface emissivities
         real      emismwstd(MWHINGE) ! MW surface emissivities
         real      rhoir(MAXEMIS) ! IR surface reflectance
         real      freqemis(MAXEMIS) ! Frequncies for emissivities/reflec
         integer   ncld         ! number of cloud layers
         real      pcldtop(MAXCLD) ! cloud top pressure
         real      tcldtop(MAXCLD) ! cloud top temperature
         real      cldfrc(MAXCLD) ! cloud fraction
         real      cldemiss(MXCEMIS,MAXCLD) ! cloud IR emissivities
         real      cldrho(MXCEMIS,MAXCLD) ! cloud IR reflectance
         real      cldfreq(MXCEMIS,MAXCLD) ! freq for cloud emissivities
         integer   nispare      ! Number of ispare used.
         integer   ispare(MAXSPARE) ! Integer spare variable
         integer   nrspare      ! Number of rspare used.
         real      rspare(MAXSPARE) ! Real spare variable

      end STRUCTURE
